<?php


# UNCOMMENT FOR DEBUGGING PHP
ini_set('display_errors', 'On');
error_reporting(E_ALL | E_STRICT);

function add_quandoo_options_page() {
	if( function_exists('acf_add_options_page') ) {
		
		acf_add_options_page(array(
			'page_title' 	=> 'Quandoo Website Settings',
			'menu_title'	=> 'Website Settings',
			'menu_slug' 	=> 'general-settings',
			'capability'	=> 'edit_posts',
			'redirect'		=> false,
			'position'      => 2,
		));

		acf_add_options_sub_page(array(
			'page_title' 	=> 'Restaurant Contact Information',
			'menu_title'	=> 'Contact Info',
			'menu_slug' 	=> 'contact-info',
			'parent_slug'	=> 'general-settings',
		));

		acf_add_options_sub_page(array(
			'page_title' 	=> 'Menu Manager',
			'menu_title'	=> 'Menu Manager',
			'menu_slug' 	=> 'menu-manager',
			'parent_slug'	=> 'general-settings',
		));

		acf_add_options_sub_page(array(
			'page_title' 	=> 'Pop-up Announcements',
			'menu_title'	=> 'Announcements',
			'menu_slug' 	=> 'announcements',
			'parent_slug'	=> 'general-settings',
		));

		acf_add_options_sub_page(array(
			'page_title' 	=> 'Quandoo Reservation Calendar',
			'menu_title'	=> 'Q Calendar',
			'menu_slug' 	=> 'q-calendar',
			'parent_slug'	=> 'general-settings',
		));

		acf_add_options_sub_page(array(
			'page_title' 	=> 'Template Selection',
			'menu_title'	=> 'Templates',
			'menu_slug' 	=> 'templates',
			'class'			=> 'qtemplates',
			'parent_slug'	=> 'general-settings',
		));

	}
}


add_action( 'init', 'add_quandoo_options_page' );



function panel($wp_customize){

	$wp_customize->add_section('qspkgen',array(
	    'title'=>'Q Spkgen',
	    'priority'=>10,
	));


	$wp_customize->add_setting('setting_spkgen',array(
	    'defaule'=>'a',
	));


	$wp_customize->add_control('ctrl_spkgen',array(
	    'label'=>'',
	    'type'=>'text',
	    'section'=>'qspkgen',
	    'settings'=>'setting_spkgen',
	));
}

add_action('customize_register','panel');


/**
 * Add ACF Pro Support
 */

# 1. customize ACF path
add_filter('acf/settings/path', 'my_acf_settings_path');
 
function my_acf_settings_path( $path ) {
 
    // update path
    $path = get_stylesheet_directory() . '/advanced-custom-fields-pro/';
    
    // return
    return $path;
    
}


# 2. customize ACF dir
add_filter('acf/settings/dir', 'my_acf_settings_dir');
 
function my_acf_settings_dir( $dir ) {
 
    // update path
    $dir = get_stylesheet_directory_uri() . '/advanced-custom-fields-pro/';
    
    // return
    return $dir;
    
}


# 3. Hide ACF field group menu item

$plugin_dir = array_reverse(explode("/", get_stylesheet_directory()));

require_once( get_stylesheet_directory() . '/advanced-custom-fields-pro/acf.php' );

require_once(get_template_directory().'/advanced-custom-fields-pro/acf-rgba-color-picker/acf-rgba-color-picker-v5.php');

include_once(get_template_directory().'/advanced-custom-fields-pro/img-select/acf-image-select.php');



add_action('muplugins_loaded', 'includeBundledACF');


# Include css file for ACF backend

add_action('acf/input/admin_head', 'my_acf_admin_head5');

function my_acf_admin_head5() {
	?>
		<style>
	<?php
	   include_once( get_stylesheet_directory() . '/css/acf-admin.css');
	?>
		</style>
	<?php  
}
 

# ACF DINAMICALLY POPULATE FIELD

function acf_load_menus( $field ) {
    $field['choices'] = array();
    if( have_rows('menu_group', 'option') ) {

        while( have_rows('menu_group', 'option') ) {
            the_row();

            $value = get_sub_field('menu_name');
            $label = get_sub_field('menu_name');

            $field['choices'][ $value ] = $label;
        }
    }
    return $field;
}

add_filter('acf/load_field/name=select_menu', 'acf_load_menus');


function acf_load_contact_locations( $field ) {
    $field['choices'] = array();
    if( have_rows('locations', 'option') ) {

        while( have_rows('locations', 'option') ) {
            the_row();

            $value = get_sub_field('location_name');
            $label = get_sub_field('location_name');

            $field['choices'][ $value ] = $label;
        }
    }
    return $field;
}

add_filter('acf/load_field/name=select_location', 'acf_load_contact_locations');


function ACF43() {
	add_filter('acf/settings/save_json', 'my_acf_json_save_point');
	 
	function my_acf_json_save_point( $path ) {
	    $path = get_stylesheet_directory() . '/acf-json/skpgen43';
	    return $path;
	}

	add_filter('acf/settings/load_json', 'my_acf_json_load_point');

	function my_acf_json_load_point( $paths ) {
	    unset($paths[0]);
	    $paths[] = get_stylesheet_directory() . '/acf-json/skpgen43';
	    return $paths;
	}
}

function ACF41() {
	add_filter('acf/settings/save_json', 'my_acf_json_save_point');
	 
	function my_acf_json_save_point( $path ) {	    
	    $path = get_stylesheet_directory() . '/acf-json/skpgen41';    
	    return $path;
	}

	add_filter('acf/settings/load_json', 'my_acf_json_load_point');

	function my_acf_json_load_point( $paths ) {	    
	    unset($paths[0]);
	    $paths[] = get_stylesheet_directory() . '/acf-json/skpgen41';
	    return $paths;
	}
}

if(isset(get_theme_mods()['setting_spkgen'])) {
	if (get_theme_mods()['setting_spkgen'] == 'qwt!gen_pr'.(90/30).'mAcf4nwp') {
		ACF43();
	} else {
		ACF41();
	}	
} else {
	ACF41();
	}
