<?php

function register_my_menus() {
  register_nav_menus(
    array(
    	'top-menu' => 'Top Menu',
    	'footer-links' => 'Footer Links',
    	'top-right-menu' => 'Top Right Menu'
  ) );
}

add_action( 'init', 'register_my_menus' );

function clean($string) {
   $string = str_replace(' ', '-', $string); // Replaces all spaces with hyphens.

   return preg_replace('/[^A-Za-z0-9\-]/', '', $string); // Removes special chars.
}


add_theme_support( 'post-thumbnails' );
//add_image_size( 'homepage', 450, 250, true );

$front_page_id = get_option( 'page_on_front' );


/**
 * Add menu meta box
 *
 * @param object $object The meta box object
 * @link https://developer.wordpress.org/reference/functions/add_meta_box/
 */
function custom_add_menu_meta_box( $object ) {
	add_meta_box( 'custom-menu-metabox', __( 'Website Sections' ), 'custom_menu_meta_box', 'nav-menus', 'side', 'default' );
	return $object;
}
add_filter( 'nav_menu_meta_box_object', 'custom_add_menu_meta_box', 10, 1);


function custom_menu_meta_box(){

	$front_page_id = get_option( 'page_on_front' );
	global $nav_menu_selected_id;
	$walker = new Walker_Nav_Menu_Checklist();

$current_tab = 'all';
$sections = get_field('website_sections', $front_page_id);
$section_arr = array();
$i=1;

	$section_arr[0] = new WP_User();
	$section_arr[0]->classes = array('home-menu-item acf-menu-item');
	$section_arr[0]->type = 'custom';
	$section_arr[0]->object_id = 'home';
	$section_arr[0]->title = '<i class="fas fa-home"></i>';
	$section_arr[0]->object = 'custom';
	$section_arr[0]->url = '#home'; 
	$section_arr[0]->attr_title = 'Home';


/* set values to required item properties */
if(!empty($sections)) {
	foreach ( $sections as $section ) {
		$section_arr[$i] = new WP_User();
		$section_arr[$i]->classes = array('acf-menu-item');
		$section_arr[$i]->type = 'custom';
		$section_arr[$i]->object_id = $section['unique_section_id'];
		$section_arr[$i]->title = $section['section_title'];
		$section_arr[$i]->object = 'custom';
		$section_arr[$i]->url = '#'.$section['unique_section_id']; 
		$section_arr[$i]->attr_title = $section['section_title'];
		$i++;

	}
}

$removed_args = array( 'action', 'customlink-tab', 'edit-menu-item', 'menu-item', 'page-tab', '_wpnonce' );
?>

<div id="authorarchive" class="categorydiv">
	<ul id="authorarchive-tabs" class="authorarchive-tabs add-menu-item-tabs">
		<li <?php echo ( 'all' == $current_tab ? ' class="tabs"' : '' ); ?>>
			<a class="nav-tab-link" data-type="tabs-panel-authorarchive-all" href="<?php if ( $nav_menu_selected_id ) echo esc_url( add_query_arg( 'authorarchive-tab', 'all', remove_query_arg( $removed_args ) ) ); ?>#tabs-panel-authorarchive-all">
				<?php _e( 'View All' ); ?>
			</a>
		</li><!-- /.tabs -->

	</ul>

<div id="tabs-panel-authorarchive-all" class="tabs-panel tabs-panel-view-all <?php echo ( 'all' == $current_tab ? 'tabs-panel-active' : 'tabs-panel-inactive' ); ?>">
	<ul id="authorarchive-checklist-all" class="categorychecklist form-no-clear">
	<?php
		echo walk_nav_menu_tree( array_map('wp_setup_nav_menu_item', $section_arr), 0, (object) array( 'walker' => $walker) );
	?>
	</ul>
</div><!-- /.tabs-panel -->



<p class="button-controls wp-clearfix">
	<span class="list-controls">
		<a href="<?php echo esc_url( add_query_arg( array( 'authorarchive-tab' => 'all', 'selectall' => 1, ), remove_query_arg( $removed_args ) )); ?>#authorarchive" class="select-all"><?php _e('Select All'); ?></a>
	</span>
	<span class="add-to-menu">
		<input type="submit"<?php wp_nav_menu_disabled_check( $nav_menu_selected_id ); ?> class="button-secondary submit-add-to-menu right" value="<?php esc_attr_e('Add to Menu'); ?>" name="add-authorarchive-menu-item" id="submit-authorarchive" />
		<span class="spinner"></span>
	</span>
</p>

</div><!-- /.categorydiv -->
<?php
}



/* Create Unique ID ACF */


class acf_field_unique_id extends acf_field {
	function __construct() {

		$this->name = 'unique_id';
		$this->label = __('Unique ID', 'acf-unique_id');
		$this->category = 'layout';
		$this->l10n = array(
		);
    	parent::__construct();
	}

	function render_field( $field ) {
		?>
		<input type="text" readonly="readonly" name="<?php echo esc_attr($field['name']) ?>" value="<?php echo esc_attr($field['value']) ?>" />
		<?php
	}

	function update_value( $value, $post_id, $field ) {
		if (!$value) {
			$value = uniqid();
		}
		return $value;
	}

	function validate_value( $valid, $value, $field, $input ){
		return true;
	}
}


// create field
new acf_field_unique_id();




/* Create Custom user capability */

function add_capability() {
	$role = get_role( 'editor' );

	$role->add_cap( 'update_themes' );
	$role->add_cap( 'update_core' );
	$role->add_cap( 'manage_options' );
	$role->add_cap( 'edit_themes' );
	$role->add_cap( 'manage_options' );
	$role->add_cap( 'customize' );
	$role->add_cap( 'edit_theme_options' );
	$role->add_cap( 'update_plugins' );
	$role->add_cap( 'activate_plugins' );
	$role->add_cap( 'edit_plugins' );
	$role->add_cap( 'install_plugins' );

	$role->remove_cap( 'edit_files' );
	$role->remove_cap( 'edit_themes' );
}


add_action( 'admin_init', 'add_capability');


/* Hide ACF menu for non-admins */

add_filter('acf/settings/show_admin', 'my_acf_show_admin');

function my_acf_show_admin( $show ) {
    
    return current_user_can('install_plugins');   
}

function getClasses($section_types, $previous_section_type, $next_section_type, $previous_section_full, $next_section_full, $next_section_background, $previous_section_background) {
    echo $section_types.'-section ';
    echo 'previous-'.$previous_section_type.' ';
    echo 'next-'.$next_section_type.' ';

    if($previous_section_full==true) {
        echo 'previous-full ';
    } 
    else if($previous_section_full==false and $previous_section_background == 'default-background') {
        echo 'previous-contained ';
    }

    if($next_section_full==true) {
        echo 'next-full ';
    }
    else if($next_section_full==false and $next_section_background == 'default-background') {
            echo 'next-contained ';
    }

    if($next_section_background == 'parallax-background' OR $next_section_background == 'color-background' OR $next_section_background == 'fixed-background') {
        echo 'next-jfc ';
    }
    if($previous_section_background == 'parallax-background' OR $previous_section_background == 'color-background' OR $previous_section_background == 'fixed-background') {
        echo 'previous-jfc ';
    }
}


add_action('admin_head', 'hidet');

function hidet() {
  echo '<style>
    .toplevel_page_general-settings .wp-submenu.wp-submenu-wrap > li:last-child {
	display: none !important;
}
  </style>';
}



function remove_acf_from_db() {
	// Remove previous field groups in DB
	$args = array(
	    'post_type'   => 'acf-field-group',
	    'post_status' => 'any',
	    'posts_per_page' => -1
	);
	
	$query = new WP_Query( $args );
	
	foreach ( $query->posts as $acf_group ) {
	    wp_delete_post( $acf_group->ID, true);
	}
}


// Disable support for comments and trackbacks in post types
function df_disable_comments_post_types_support() {
	$post_types = get_post_types();
	foreach ($post_types as $post_type) {
		if(post_type_supports($post_type, 'comments')) {
			remove_post_type_support($post_type, 'comments');
			remove_post_type_support($post_type, 'trackbacks');
		}
	}
}
add_action('admin_init', 'df_disable_comments_post_types_support');

// Close comments on the front-end
function df_disable_comments_status() {
	return false;
}
add_filter('comments_open', 'df_disable_comments_status', 20, 2);
add_filter('pings_open', 'df_disable_comments_status', 20, 2);

// Hide existing comments
function df_disable_comments_hide_existing_comments($comments) {
	$comments = array();
	return $comments;
}
add_filter('comments_array', 'df_disable_comments_hide_existing_comments', 10, 2);

// Remove comments page in menu
function df_disable_comments_admin_menu() {
	remove_menu_page('edit-comments.php');
}
add_action('admin_menu', 'df_disable_comments_admin_menu');

// Redirect any user trying to access comments page
function df_disable_comments_admin_menu_redirect() {
	global $pagenow;
	if ($pagenow === 'edit-comments.php') {
		wp_redirect(admin_url()); exit;
	}
}
add_action('admin_init', 'df_disable_comments_admin_menu_redirect');

// Remove comments metabox from dashboard
function df_disable_comments_dashboard() {
	remove_meta_box('dashboard_recent_comments', 'dashboard', 'normal');
}
add_action('admin_init', 'df_disable_comments_dashboard');

// Remove comments links from admin bar
function df_disable_comments_admin_bar() {
	if (is_admin_bar_showing()) {
		remove_action('admin_bar_menu', 'wp_admin_bar_comments_menu', 60);
	}
}
add_action('init', 'df_disable_comments_admin_bar');


// disable Gutenberg for posts
add_filter('use_block_editor_for_post', '__return_false', 10);

// disable Gutenberg for post types
add_filter('use_block_editor_for_post_type', '__return_false', 10);


//Comment this function before acf sync
//add_filter('after_setup_theme','remove_acf_from_db');